@@ -5,7 +5,7 @@
 #  File author(s): Thomas Cokelaer <cokelaer@gmail.com>
 #
 """Common tools to get the correct filename and pathname. """
-__version__ = "$Rev: 32 $"
+__version__ = "$Rev: 36 $"
 import pkg_resources
 try:
     version = pkg_resources.require("easydev")[0].version
@@ -43,3 +43,6 @@ from url import *
 
 #import dependencies
 from dependencies import get_dependencies
+
+import multicore
+from multicore import *
